==> hindent-5.3.4-218-x86_64.pkg.tar.zst: usr/share/haskell/register/hindent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hindent
version:              5.3.4
visibility:           public
id:                   hindent-5.3.4-AZd9zlQzsNl29a6MTDUvZS
key:                  hindent-5.3.4-AZd9zlQzsNl29a6MTDUvZS
license:              BSD-3-Clause
copyright:            2014 Chris Done, 2015 Andrew Gibiansky, 2021 Mihai Maruseac
maintainer:           Mihai Maruseac
author:
    Mihai Maruseac, Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker

stability:            Unstable
homepage:             https://github.com/mihaimaruseac/hindent
synopsis:             Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable.

    See the Github page for usage\/explanation: <https://github.com/mihaimaruseac/hindent>

category:             Development
abi:                  c573a50bcace081f8ca2c953af9b95bc
exposed:              True
exposed-modules:
    HIndent HIndent.CabalFile HIndent.CodeBlock HIndent.Pretty
    HIndent.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hindent-5.3.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hindent-5.3.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hindent-5.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hindent
hs-libraries:         HShindent-5.3.4-AZd9zlQzsNl29a6MTDUvZS
depends:
    Cabal-3.8.1.0 base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.7.1 exceptions-0.10.5 filepath-1.4.2.2
    haskell-src-exts-1.23.1-BzyMXcZNztJ6lgISqRJKxQ
    monad-loops-0.4.3-KaRiS5mJjkQ1zBkxxbNC2Z mtl-2.2.2 text-2.0.2
    transformers-0.5.6.2 utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    yaml-0.11.11.2-9mPv4ErasFx4d9CJdguPCE

haddock-interfaces:   /usr/share/doc/hindent/html/hindent.haddock
haddock-html:         /usr/share/doc/hindent/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hindent-5.3.4-219-x86_64.pkg.tar.zst: usr/share/haskell/register/hindent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hindent
version:              5.3.4
visibility:           public
id:                   hindent-5.3.4-7oCTa23d6eGCDFOgL4jPJu
key:                  hindent-5.3.4-7oCTa23d6eGCDFOgL4jPJu
license:              BSD-3-Clause
copyright:            2014 Chris Done, 2015 Andrew Gibiansky, 2021 Mihai Maruseac
maintainer:           Mihai Maruseac
author:
    Mihai Maruseac, Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker

stability:            Unstable
homepage:             https://github.com/mihaimaruseac/hindent
synopsis:             Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable.

    See the Github page for usage\/explanation: <https://github.com/mihaimaruseac/hindent>

category:             Development
abi:                  d2281fd40c7deefd9250df6aaae061a8
exposed:              True
exposed-modules:
    HIndent HIndent.CabalFile HIndent.CodeBlock HIndent.Pretty
    HIndent.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hindent-5.3.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hindent-5.3.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hindent-5.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hindent
hs-libraries:         HShindent-5.3.4-7oCTa23d6eGCDFOgL4jPJu
depends:
    Cabal-3.8.1.0 base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.7.1 exceptions-0.10.5 filepath-1.4.2.2
    haskell-src-exts-1.23.1-BzyMXcZNztJ6lgISqRJKxQ
    monad-loops-0.4.3-KaRiS5mJjkQ1zBkxxbNC2Z mtl-2.2.2 text-2.0.2
    transformers-0.5.6.2 utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    yaml-0.11.11.2-CNlfHEXg6l9FWbwNSPQdwm

haddock-interfaces:   /usr/share/doc/hindent/html/hindent.haddock
haddock-html:         /usr/share/doc/hindent/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
